"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseDockerToEasypanel = void 0;
const schema_1 = require("./schema");
const serviceParser_1 = require("./serviceParser");
const ymlInformationParser_1 = require("./ymlInformationParser");
function parseDockerToEasypanel(file, projectName) {
    if (!(0, ymlInformationParser_1.isVersion3)(file.version))
        throw new Error("please use docker-compose version 3.x");
    const serviceKeys = Object.keys(file.services);
    const easypanelServices = serviceKeys.map((serviceKey) => {
        const { container_name, environment, image, ports, volumes, command } = file.services[serviceKey];
        const serviceName = container_name || serviceKey;
        const serviceType = (0, ymlInformationParser_1.getEasypanelServiceType)({ environment, image });
        console.log(serviceType);
        if (serviceType === "mongo") {
            return {
                type: "mongo",
                data: {
                    projectName,
                    serviceName,
                    image: image !== serviceType ? image : undefined,
                    password: (environment && environment.MONGO_INITDB_ROOT_PASSWORD) ||
                        (0, schema_1.randomPassword)(),
                },
            };
        }
        else if (serviceType === "postgres") {
            return {
                type: "postgres",
                data: {
                    projectName,
                    serviceName,
                    image: image !== serviceType ? image : undefined,
                    password: (environment && environment.POSTGRES_PASSWORD) ||
                        (0, schema_1.randomPassword)(),
                },
            };
        }
        else if (serviceType === "mysql") {
            return {
                type: "mysql",
                data: {
                    projectName,
                    serviceName,
                    image: image !== serviceType ? image : undefined,
                    rootPassword: (environment && environment.MYSQL_ROOT_PASSWORD) ||
                        (0, schema_1.randomPassword)(),
                    password: (environment && environment.MYSQL_PASSWORD) || (0, schema_1.randomPassword)(),
                },
            };
        }
        else if (serviceType === "redis") {
            return {
                type: "redis",
                data: {
                    projectName,
                    serviceName,
                    image: image !== serviceType ? image : undefined,
                    password: (environment && environment.REDIS_PASSWORD) || (0, schema_1.randomPassword)(),
                },
            };
        }
        else {
            return (0, serviceParser_1.parseAppService)(projectName, serviceName, image || "", ports, environment, volumes, command);
        }
    });
    return {
        services: easypanelServices,
    };
}
exports.parseDockerToEasypanel = parseDockerToEasypanel;
