"use strict";
/**
 * this code defines the diffrent easypanel schemas
 * This Code comes from the github repo easypanel/easypanel-templates
 * main contributer and developer of easypanel: https://github.com/deiucanta
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.supportedServiceTypes = exports.templateSchema = exports.singleServiceSchema = exports.redisSchema = exports.postgresSchema = exports.mariadbSchema = exports.mysqlSchema = exports.mongoSchema = exports.appSchema = exports.appDeploySchema = exports.appMountsSchema = exports.passwordRule = exports.portRule = exports.domainRule = exports.volumeNameRule = exports.serviceNameRule = exports.projectNameRule = exports.randomPassword = void 0;
const zod_1 = require("zod");
const crypto_1 = require("crypto");
const randomPassword = () => (0, crypto_1.randomBytes)(10).toString("hex");
exports.randomPassword = randomPassword;
exports.projectNameRule = zod_1.z
    .string()
    .regex(/^[a-z0-9-_]+$/, "Invalid name. Use lowercase letters (a-z), digits (0-9), dash (-), underscore (_).");
exports.serviceNameRule = zod_1.z
    .string()
    .regex(/^[a-z0-9-_]+$/, "Invalid name. Use lowercase letters (a-z), digits (0-9), dash (-), underscore (_).");
exports.volumeNameRule = zod_1.z
    .string()
    .regex(/^[a-z0-9-_]+$/, "Invalid name. Use lowercase letters (a-z), digits (0-9), dash (-), underscore (_).");
exports.domainRule = zod_1.z.string().regex(/^[a-z0-9.-]+$/);
exports.portRule = zod_1.z.number().min(0).max(65535);
exports.passwordRule = zod_1.z.string().default(exports.randomPassword);
exports.appMountsSchema = zod_1.z
    .array(zod_1.z.union([
    zod_1.z.object({
        type: zod_1.z.literal("bind"),
        hostPath: zod_1.z.string().min(1),
        mountPath: zod_1.z.string().min(1),
    }),
    zod_1.z.object({
        type: zod_1.z.literal("volume"),
        name: exports.volumeNameRule,
        mountPath: zod_1.z.string().min(1),
    }),
    zod_1.z.object({
        type: zod_1.z.literal("file"),
        content: zod_1.z.string(),
        mountPath: zod_1.z.string().min(1),
    }),
]))
    .default([]);
exports.appDeploySchema = zod_1.z
    .object({
    replicas: zod_1.z.number().default(1),
    command: zod_1.z.string().nullable().default(null),
    zeroDowntime: zod_1.z.boolean().default(true),
})
    .default({});
exports.appSchema = zod_1.z.object({
    projectName: exports.projectNameRule,
    serviceName: exports.serviceNameRule,
    source: zod_1.z
        .union([
        zod_1.z.object({
            type: zod_1.z.literal("image"),
            image: zod_1.z.string(),
        }),
        zod_1.z.object({
            type: zod_1.z.literal("github"),
            owner: zod_1.z.string(),
            repo: zod_1.z.string(),
            ref: zod_1.z.string(),
            path: zod_1.z.string(),
            autoDeploy: zod_1.z.boolean(),
        }),
    ])
        .optional(),
    env: zod_1.z.string().default(""),
    proxy: zod_1.z
        .object({
        port: zod_1.z.number().default(80),
        secure: zod_1.z.boolean().default(true),
    })
        .default({}),
    deploy: exports.appDeploySchema,
    domains: zod_1.z
        .array(zod_1.z.object({
        name: exports.domainRule,
    }))
        .default([]),
    mounts: exports.appMountsSchema,
    ports: zod_1.z
        .array(zod_1.z.object({
        published: zod_1.z.number(),
        target: zod_1.z.number(),
    }))
        .default([]),
});
exports.mongoSchema = zod_1.z.object({
    projectName: exports.projectNameRule,
    serviceName: exports.serviceNameRule,
    image: zod_1.z.string().optional(),
    password: exports.passwordRule,
});
exports.mysqlSchema = zod_1.z.object({
    projectName: exports.projectNameRule,
    serviceName: exports.serviceNameRule,
    image: zod_1.z.string().optional(),
    password: exports.passwordRule,
    rootPassword: exports.passwordRule,
});
exports.mariadbSchema = zod_1.z.object({
    projectName: exports.projectNameRule,
    serviceName: exports.serviceNameRule,
    image: zod_1.z.string().optional(),
    password: exports.passwordRule,
    rootPassword: exports.passwordRule,
});
exports.postgresSchema = zod_1.z.object({
    projectName: exports.projectNameRule,
    serviceName: exports.serviceNameRule,
    image: zod_1.z.string().optional(),
    password: exports.passwordRule,
});
exports.redisSchema = zod_1.z.object({
    projectName: exports.projectNameRule,
    serviceName: exports.serviceNameRule,
    image: zod_1.z.string().optional(),
    password: exports.passwordRule,
});
exports.singleServiceSchema = zod_1.z.union([
    zod_1.z.object({
        type: zod_1.z.literal("app"),
        data: exports.appSchema,
    }),
    zod_1.z.object({
        type: zod_1.z.literal("mysql"),
        data: exports.mysqlSchema,
    }),
    zod_1.z.object({
        type: zod_1.z.literal("mariadb"),
        data: exports.mariadbSchema,
    }),
    zod_1.z.object({
        type: zod_1.z.literal("mongo"),
        data: exports.mongoSchema,
    }),
    zod_1.z.object({
        type: zod_1.z.literal("postgres"),
        data: exports.postgresSchema,
    }),
    zod_1.z.object({
        type: zod_1.z.literal("redis"),
        data: exports.redisSchema,
    }),
]);
exports.templateSchema = zod_1.z.object({
    services: zod_1.z.array(exports.singleServiceSchema),
});
exports.supportedServiceTypes = ["app", "postgres", "mongo", "redis", "mysql"];
