"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseAppService = exports.parseRedisService = exports.parseMySqlService = exports.parsePostgresService = exports.parseMongoService = void 0;
function parseMongoService(projectName, serviceName, password, image) {
    return {
        type: "mongo",
        data: {
            projectName,
            serviceName,
            password,
            image,
        },
    };
}
exports.parseMongoService = parseMongoService;
function parsePostgresService(projectName, serviceName, password, image) {
    return {
        type: "postgres",
        data: {
            projectName,
            serviceName,
            password,
            image,
        },
    };
}
exports.parsePostgresService = parsePostgresService;
function parseMySqlService(projectName, serviceName, password, rootPassword, image) {
    return {
        type: "mysql",
        data: {
            projectName,
            serviceName,
            password,
            image,
            rootPassword,
        },
    };
}
exports.parseMySqlService = parseMySqlService;
function parseRedisService(projectName, serviceName, password, image) {
    return {
        type: "redis",
        data: {
            projectName,
            serviceName,
            password,
            image,
        },
    };
}
exports.parseRedisService = parseRedisService;
function parseAppService(projectName, serviceName, image, ports, environment, volumes, command) {
    return {
        type: "app",
        data: {
            projectName,
            serviceName,
            source: {
                type: "image",
                image,
            },
            deploy: {
                command: command,
            },
            ports: ports === null || ports === void 0 ? void 0 : ports.map((port) => {
                return {
                    published: parseInt(port.split(":")[0]),
                    target: parseInt(port.split(":")[1]),
                };
            }),
            env: environment
                ? Object.keys(environment)
                    .map((key) => `${key}=${environment[key]}`)
                    .join("\n")
                : undefined,
            mounts: volumes === null || volumes === void 0 ? void 0 : volumes.map((volume) => {
                const hostPathOrName = volume.split(":")[0];
                const mountPath = volume.split(":")[1];
                if (hostPathOrName.split("")[0] === "/" ||
                    hostPathOrName.split("")[0] === ".") {
                    return {
                        type: "bind",
                        hostPath: hostPathOrName,
                        mountPath,
                    };
                }
                return {
                    type: "volume",
                    name: hostPathOrName,
                    mountPath,
                };
            }),
        },
    };
}
exports.parseAppService = parseAppService;
